aboutsummaryrefslogtreecommitdiff
path: root/src/odbc
diff options
context:
space:
mode:
authorMickaël Rémond <mickael.remond@process-one.net>2007-12-24 13:57:53 +0000
committerMickaël Rémond <mickael.remond@process-one.net>2007-12-24 13:57:53 +0000
commit22f928122f46136eb428efdac5f8d3cff4a2dcae (patch)
tree7a903401a33c8118cd8cd7ba1666b9a7f3215f13 /src/odbc
parent* applied copyright patch 2. (diff)
* Applied copyright patch 3.
SVN Revision: 1113
Diffstat (limited to 'src/odbc')
-rw-r--r--src/odbc/ejabberd_odbc.erl26
-rw-r--r--src/odbc/ejabberd_odbc_sup.erl26
-rw-r--r--src/odbc/mssql.sql20
-rw-r--r--src/odbc/mysql.sql19
-rw-r--r--src/odbc/odbc_queries.erl31
-rw-r--r--src/odbc/pg.sql18
6 files changed, 128 insertions, 12 deletions
diff --git a/src/odbc/mssql.sql b/src/odbc/mssql.sql
index 7783476ba..3e9d908fd 100644
--- a/src/odbc/mssql.sql
+++ b/src/odbc/mssql.sql
@@ -1,3 +1,23 @@
+/*
+ * ejabberd, Copyright (C) 2002-2007 Process-one
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+ * 02111-1307 USA
+ *
+ */
+
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
diff --git a/src/odbc/mysql.sql b/src/odbc/mysql.sql
index 20c53b577..a6df394f0 100644
--- a/src/odbc/mysql.sql
+++ b/src/odbc/mysql.sql
@@ -1,3 +1,22 @@
+--
+-- ejabberd, Copyright (C) 2002-2007 Process-one
+--
+-- This program is free software; you can redistribute it and/or
+-- modify it under the terms of the GNU General Public License as
+-- published by the Free Software Foundation; either version 2 of the
+-- License, or (at your option) any later version.
+--
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+-- General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with this program; if not, write to the Free Software
+-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+-- 02111-1307 USA
+--
+
-- Needs MySQL (at least 4.0.x) with innodb back-end
SET table_type=InnoDB;
diff --git a/src/odbc/odbc_queries.erl b/src/odbc/odbc_queries.erl
index e4daefbb7..38e9a33d0 100644
--- a/src/odbc/odbc_queries.erl
+++ b/src/odbc/odbc_queries.erl
@@ -1,8 +1,31 @@
-%% Copyrigh 2006 Process-one
-%% This module is intended to take into account relational databases behaviour
-%% differences
+%%%----------------------------------------------------------------------
+%%% File : odbc_queries.erl
+%%% Author : Mickael Remond <mremond@process-one.net>
+%%% Purpose : ODBC queries dependind on back-end
+%%% Created : by Mickael Remond <mremond@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
+%%%----------------------------------------------------------------------
+
-module(odbc_queries).
--author("mickael.remond@process-one.net").
+-author("mremond@process-one.net").
-export([get_db_type/0,
sql_transaction/2,
diff --git a/src/odbc/pg.sql b/src/odbc/pg.sql
index 1fd81645d..13a30994a 100644
--- a/src/odbc/pg.sql
+++ b/src/odbc/pg.sql
@@ -1,3 +1,21 @@
+--
+-- ejabberd, Copyright (C) 2002-2007 Process-one
+--
+-- This program is free software; you can redistribute it and/or
+-- modify it under the terms of the GNU General Public License as
+-- published by the Free Software Foundation; either version 2 of the
+-- License, or (at your option) any later version.
+--
+-- This program is distributed in the hope that it will be useful,
+-- but WITHOUT ANY WARRANTY; without even the implied warranty of
+-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+-- General Public License for more details.
+--
+-- You should have received a copy of the GNU General Public License
+-- along with this program; if not, write to the Free Software
+-- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+-- 02111-1307 USA
+--
CREATE TABLE users (
username text PRIMARY KEY,
diff --git a/src/odbc/ejabberd_odbc.erl b/src/odbc/ejabberd_odbc.erl
index a8d9fcda8..173543b0d 100644
--- a/src/odbc/ejabberd_odbc.erl
+++ b/src/odbc/ejabberd_odbc.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_odbc.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : Serve ODBC connection
-%%% Created : 8 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 8 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_odbc).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
-behaviour(gen_server).
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_odbc.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : Serve ODBC connection
diff --git a/src/odbc/ejabberd_odbc_sup.erl b/src/odbc/ejabberd_odbc_sup.erl
index 4c5e1e18d..9af2f564f 100644
--- a/src/odbc/ejabberd_odbc_sup.erl
+++ b/src/odbc/ejabberd_odbc_sup.erl
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_odbc_sup.erl
%%% Author : Alexey Shchepin <alexey@sevcom.net>
%%% Purpose : ODBC connections supervisor
-%%% Created : 22 Dec 2004 by Alexey Shchepin <alexey@sevcom.net>
-%%% Id : $Id$
+%%% Created : 22 Dec 2004 by Alexey Shchepin <alexey@process-one.net>
+%%%
+%%%
+%%% ejabberd, Copyright (C) 2002-2007 Process-one
+%%%
+%%% This program is free software; you can redistribute it and/or
+%%% modify it under the terms of the GNU General Public License as
+%%% published by the Free Software Foundation; either version 2 of the
+%%% License, or (at your option) any later version.
+%%%
+%%% This program is distributed in the hope that it will be useful,
+%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
+%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+%%% General Public License for more details.
+%%%
+%%% You should have received a copy of the GNU General Public License
+%%% along with this program; if not, write to the Free Software
+%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
+%%% 02111-1307 USA
+%%%
%%%----------------------------------------------------------------------
-module(ejabberd_odbc_sup).
--author('alexey@sevcom.net').
+-author('alexey@process-one.net').
%% API
-export([start_link/1,
@@ -1,13 +1,31 @@
%%%----------------------------------------------------------------------
%%% File : ejabberd_odbc_sup.erl
-%%% Author : Alexey Shchepin <alexey@sevcom.net>
+%%% Author : Alexey Shchepin <alexey@process-one.net>
%%% Purpose : ODBC connections supervisor